# Py_DI - Python Container of Dependency Injection (IOC) implementation

## Authors
- [Moises P. Sena](http://moisespsena.com)

## Issues

[Issues on GitHub](https://github.com/moisespsena/py_di/issues).

## Installation

### By pip:

```bash
sudo pip install py_di
```

### Manual:

For default python executable:

```bash
git clone https://github.com/moisespsena/py_di py_di
cd py_di
sudo python setup.py install
```

For another python executable:

```bash
sudo python3 setup.py install
```

## Example:

See [tests](https://github.com/moisespsena/py_di/blob/master/tests/p/test_all.py) for more details.